@@ -102,9 +102,9 @@ class Alias:
 
             if VERBOSE:
                 try:
-                    logger.info("Loading completed." % fileName)
+                    logger.info("Loading completed.")
                 except Exception:
-                    print("Loading completed. " % fileName)
+                    print("Loading completed.")
 
         except Exception as e:
             self._reset()
