@@ -29,10 +29,12 @@ __all__ = ['Mod', 'VERSION']
 class Mod:
     '''The class for parsing a piece of a mod file from the same chromosome.'''
 
-    def __init__(self, fileName):
+    def __init__(self, fileName, checkMode=True):
         self.fileName = fileName
-        self.check_and_fix()
-        self.build_index(force=True)
+        if checkMode:
+            self.check_and_fix()
+            self.build_index(force=True)
+
         self.load_meta()
 
         #Initialize tabix engine
